@@ -9,11 +9,12 @@
 #' @param prob_each Use for a multi-arm design in which the values of prob_each determine the probabilties of assignment to each treatment condition. prob_each must be a numeric vector giving the probability of assignment to each condition. All entries must be nonnegative real numbers between 0 and 1 inclusive and the total must sum to 1. Because of integer issues, the exact number of units assigned to each condition may differ (slightly) from assignment to assignment, but the overall probability of assignment is exactly prob_each. (optional)
 #' @param block_m Use for a two-arm design in which block_m describes the number of units to assign to treatment within each block. Note that in previous versions of randomizr, block_m behaved like block_m_each.
 #' @param block_m_each Use for a multi-arm design in which the values of block_m_each determine the number of units (or clusters) assigned to each condition. block_m_each must be a matrix with the same number of rows as blocks and the same number of columns as treatment arms. Cell entries are the number of units (or clusters) to be assigned to each treatment arm within each block. The rows should respect the ordering of the blocks as determined by sort(unique(block_var)). The columns should be in the order of condition_names, if specified.
+#' @param block_prob Use for a two-arm design in which block_prob describes the probability of assignment to treatment within each block. Differs from prob in that the probability of assignment can vary across blocks.
 #' @param block_prob_each Use for a multi-arm design in which the values of block_prob_each determine the probabilties of assignment to each treatment condition. block_prob_each must be a matrix with the same number of rows as blocks and the same number of columns as treatment arms. Cell entries are the probabilites of assignment to treatment within each block. The rows should respect the ordering of the blocks as determined by sort(unique(block_var)). Use only if the probabilities of assignment should vary by block, otherwise use prob_each. Each row of block_prob_each must sum to 1.
 #' @param num_arms The number of treatment arms. If unspecified, num_arms will be determined from the other arguments. (optional)
 #' @param condition_names A character vector giving the names of the treatment groups. If unspecified, the treatment groups will be named 0 (for control) and 1 (for treatment) in a two-arm trial and T1, T2, T3, in a multi-arm trial. An execption is a two-group design in which num_arms is set to 2, in which case the condition names are T1 and T2, as in a multi-arm trial with two arms. (optional)
 #' @param simple logical, defaults to FALSE. If TRUE, simple random assignment is used. When simple = TRUE, please do not specify m, m_each, block_m, or block_m_each.
-#' @param balance_load logical, defaults to FALSE. This feature is experimental. If set to TRUE, the function will resolve rounding problems by randomly assigning "remainder" units to each possible treatment condition with equal probability, while ensuring that the total number of units assigned to each condition does not vary greatly from assignment to assignment. However, the true probabiltiies of assignment may be different from the nominal probabilities specified in prob_each or block_prob_each. Please use with caution and perform many tests before using in a real research scenario.
+#' @param check_inputs logical. Defaults to TRUE.
 #'
 #' @return A list of class "ra_declaration".  The list has five entries:
 #'   $ra_function, a function that generates random assignments accroding to the declaration.
@@ -96,26 +97,29 @@ declare_ra <- function(N = NULL,
                        prob_each = NULL,
                        block_m = NULL,
                        block_m_each = NULL,
+                       block_prob = NULL,
                        block_prob_each = NULL,
                        num_arms = NULL,
                        condition_names = NULL,
                        simple = FALSE,
-                       balance_load = FALSE) {
-  
-  check_inputs <- check_randomizr_arguments(
-    N = N,
-    block_var = block_var,
-    clust_var = clust_var,
-    m = m,
-    m_each = m_each,
-    prob = prob,
-    prob_each = prob_each,
-    block_m = block_m,
-    block_m_each = block_m_each,
-    block_prob_each = block_prob_each,
-    num_arms = num_arms,
-    condition_names = condition_names
-  )
+                       check_inputs = TRUE) {
+  if (check_inputs) {
+    check_inputs <- check_randomizr_arguments(
+      N = N,
+      block_var = block_var,
+      clust_var = clust_var,
+      m = m,
+      m_each = m_each,
+      prob = prob,
+      prob_each = prob_each,
+      block_m = block_m,
+      block_m_each = block_m_each,
+      block_prob = block_prob,
+      block_prob_each = block_prob_each,
+      num_arms = num_arms,
+      condition_names = condition_names
+    )
+  }
   # Determine ra_type
   if (simple == FALSE) {
     ra_type <- "complete"
@@ -200,23 +204,23 @@ declare_ra <- function(N = NULL,
         block_m_each = block_m_each,
         prob = prob,
         prob_each = prob_each,
+        block_prob = block_prob,
         block_prob_each = block_prob_each,
-        condition_names = condition_names,
-        balance_load = balance_load
+        condition_names = condition_names
       )
     }
     
     probabilities_matrix <-
       block_ra_probabilities(
         block_var = block_var,
-        num_arms = num_arms,
         block_m = block_m,
         block_m_each = block_m_each,
         prob = prob,
         prob_each = prob_each,
+        block_prob = block_prob,
         block_prob_each = block_prob_each,
         condition_names = condition_names,
-        balance_load = balance_load
+        num_arms = num_arms
       )
   }
   
@@ -254,14 +258,14 @@ declare_ra <- function(N = NULL,
       block_and_cluster_ra(
         clust_var = clust_var,
         block_var = block_var,
-        num_arms = num_arms,
+        prob = prob,
+        prob_each = prob_each,
         block_m = block_m,
         block_m_each = block_m_each,
-        prob = prob,
+        block_prob = block_prob,
         block_prob_each = block_prob_each,
-        prob_each = prob_each,
         condition_names = condition_names,
-        balance_load = balance_load
+        num_arms = num_arms
       )
     }
     
@@ -269,14 +273,14 @@ declare_ra <- function(N = NULL,
       block_and_cluster_ra_probabilities(
         clust_var = clust_var,
         block_var = block_var,
-        block_m = block_m,
-        block_m_each = block_m_each,
         prob = prob,
         prob_each = prob_each,
+        block_prob = block_prob,
+        block_m = block_m,
+        block_m_each = block_m_each,
         block_prob_each = block_prob_each,
         num_arms = num_arms,
-        condition_names = condition_names,
-        balance_load = balance_load
+        condition_names = condition_names
       )
     
   }
@@ -294,30 +298,76 @@ declare_ra <- function(N = NULL,
   
 }
 
-#' Conduct a declared random assignment.
+#' Conduct a random assignment
+#'
+#' You can either give conduct_ra() an ra_declaration, as created by \code{\link{declare_ra}} or you can specify the other arguments to describe a random assignment procedure.
 #'
 #' @param ra_declaration A random assignment declaration, created by \code{\link{declare_ra}}.
-#'
+#' @inheritParams declare_ra
 #' @examples
-#' declaration <- declare_ra(N=100, m_each=c(30, 30, 40))
+#' declaration <- declare_ra(N = 100, m_each = c(30, 30, 40))
 #' Z <- conduct_ra(ra_declaration = declaration)
 #' table(Z)
 #'
+#' # equivalent to
+#'
+#' Z <- conduct_ra(N = 100, m_each = c(30, 30, 40))
+#' table(Z)
+#'
 #' @export
-conduct_ra <- function(ra_declaration) {
-  # checks
-  if (class(ra_declaration) != "ra_declaration") {
-    stop("You must provide a random assignment declaration created by declare_ra().")
+conduct_ra <- function(ra_declaration = NULL,
+                       N = NULL,
+                       block_var = NULL,
+                       clust_var = NULL,
+                       m = NULL,
+                       m_each = NULL,
+                       prob = NULL,
+                       prob_each = NULL,
+                       block_m = NULL,
+                       block_m_each = NULL,
+                       block_prob = NULL,
+                       block_prob_each = NULL,
+                       num_arms = NULL,
+                       condition_names = NULL,
+                       simple = FALSE,
+                       check_inputs = TRUE) {
+  if (!is.null(ra_declaration)) {
+    if (class(ra_declaration) != "ra_declaration") {
+      stop("You must provide a random assignment declaration created by declare_ra().")
+    }
+  } else{
+    ra_declaration <-
+      declare_ra(
+        N = N,
+        block_var = block_var,
+        clust_var = clust_var,
+        m = m,
+        m_each = m_each,
+        prob = prob,
+        prob_each = prob_each,
+        block_m = block_m,
+        block_m_each = block_m_each,
+        block_prob = block_prob,
+        block_prob_each = block_prob_each,
+        num_arms = num_arms,
+        condition_names = condition_names,
+        simple = simple,
+        check_inputs = check_inputs
+      )
+    
   }
   return(ra_declaration$ra_function())
 }
 
 #' Obtain the probabilities of units being in the conditions that they are in.
 #'
+#' You can either give obtain_condition_probabilities() an ra_declaration, as created by \code{\link{declare_ra}} or you can specify the other arguments to describe a random assignment procedure.\cr \cr
 #' This function is especially useful when units have different probabilties of assignment and the analyst plans to use inverse-probability weights.
 #'
+#'
 #' @param ra_declaration A random assignment declaration, created by \code{\link{declare_ra}}.
 #' @param assignment A vector of random assignments, often created by \code{\link{conduct_ra}}.
+#' @inheritParams declare_ra
 #'
 #' @examples
 #'
@@ -333,18 +383,67 @@ conduct_ra <- function(ra_declaration) {
 #' observed_probabilities <-
 #'    obtain_condition_probabilities(ra_declaration = declaration, assignment = Z)
 #'
+#'
 #' # Probabilities in the control group:
 #' table(observed_probabilities[Z == 0], block_var[Z == 0])
 #'
 #' # Probabilities in the treatment group:
 #' table(observed_probabilities[Z == 1], block_var[Z == 1])
 #'
+#'
+#' # Sometimes it is convenient to skip the declaration step
+#' Z <- conduct_ra(block_var = block_var, block_m_each = block_m_each)
+#' observed_probabilities <-
+#'    obtain_condition_probabilities(assignment = Z,
+#'                                   block_var = block_var,
+#'                                   block_m_each = block_m_each)
+#' table(observed_probabilities[Z == 0], block_var[Z == 0])
+#' table(observed_probabilities[Z == 1], block_var[Z == 1])
+#'
 #' @export
 obtain_condition_probabilities <-
-  function(ra_declaration, assignment) {
+  function(ra_declaration = NULL,
+           assignment,
+           N = NULL,
+           block_var = NULL,
+           clust_var = NULL,
+           m = NULL,
+           m_each = NULL,
+           prob = NULL,
+           prob_each = NULL,
+           block_m = NULL,
+           block_m_each = NULL,
+           block_prob = NULL,
+           block_prob_each = NULL,
+           num_arms = NULL,
+           condition_names = NULL,
+           simple = FALSE) {
     # checks
-    if (class(ra_declaration) != "ra_declaration") {
-      stop("You must provide a random assignment declaration created by declare_ra().")
+    if (!is.null(ra_declaration)) {
+      if (class(ra_declaration) != "ra_declaration") {
+        stop("You must provide a random assignment declaration created by declare_ra().")
+      }
+    } else{
+      if (is.null(N)) {
+        N <- length(assignment)
+      }
+      ra_declaration <-
+        declare_ra(
+          N = N,
+          block_var = block_var,
+          clust_var = clust_var,
+          m = m,
+          m_each = m_each,
+          prob = prob,
+          prob_each = prob_each,
+          block_m = block_m,
+          block_m_each = block_m_each,
+          block_prob = block_prob,
+          block_prob_each = block_prob_each,
+          num_arms = num_arms,
+          condition_names = condition_names,
+          simple = simple
+        )
     }
     
     probabilities_matrix <- ra_declaration$probabilities_matrix
