@@ -35,18 +35,23 @@ simple_ra_probabilities <-
            prob = NULL,
            prob_each = NULL,
            num_arms = NULL,
-           condition_names = NULL) {
-    clean_inputs <-
-      check_randomizr_arguments(
-        N = N,
-        prob = prob,
-        prob_each = prob_each,
-        num_arms = num_arms,
-        condition_names = condition_names
-      )
+           condition_names = NULL,
+           check_inputs = TRUE) {
     
-    num_arms <- clean_inputs$num_arms
-    condition_names <- clean_inputs$condition_names
+    if(check_inputs) {
+      
+      check_inputs <-
+        check_randomizr_arguments(
+          N = N,
+          prob = prob,
+          prob_each = prob_each,
+          num_arms = num_arms,
+          condition_names = condition_names
+        )
+      
+    }
+    num_arms <- check_inputs$num_arms
+    condition_names <- check_inputs$condition_names
     
     # Three easy cases
     
